@@ -7,8 +7,8 @@ from pathlib import Path
 import yaml
 import io
 
-from qary.config import DATA_DIR, DOMAINS
-from qary.config import FINISH_STATE_NAME, EXIT_STATE_NAME, DEFAULT_STATE_NAME
+from qary.constants import DATA_DIR, DOMAINS
+from qary.constants import FINISH_STATE_NAME, EXIT_STATE_NAME, DEFAULT_STATE_NAME
 from qary.etl.utils import normalize_keys, normalize_name
 from qary.etl.nesting import default_normalizer
 
