@@ -7,7 +7,7 @@ from qary.etl.utils import normalize_name  # , normalize_wikititle, slugify
 from qary.etl.nesting import default_normalizer
 import yaml
 
-from qary.config import DATA_DIR, DOMAINS
+from qary.constants import DATA_DIR, DOMAINS
 
 try:
     from collections.abc import Mapping
@@ -15,9 +15,9 @@ except ImportError:  # python <3.7
     from collections import Mapping
 
 
-from qary.config import WELCOME_STATE_NAME, FINISH_STATE_NAME, DEFAULT_STATE_NAME
-from qary.config import DEFAULT_BOT_USERNAME, EXIT_STATE_NAME
-# from qary.config import EXIT_STATE_TURN_DICT, EXIT_BOT_STATEMENTS
+from qary.constants import WELCOME_STATE_NAME, FINISH_STATE_NAME, DEFAULT_STATE_NAME
+from qary.constants import DEFAULT_BOT_USERNAME, EXIT_STATE_NAME
+# from qary.constants import EXIT_STATE_TURN_DICT, EXIT_BOT_STATEMENTS
 
 
 # FIXME: make this a config option and dont default to a test file
