@@ -13,7 +13,7 @@ from collections import abc
 import io
 import logging
 from pathlib import Path
-from qary.config import DATA_DIR
+from qary.constants import DATA_DIR
 import time
 import yaml
 
@@ -21,7 +21,7 @@ import numpy as np
 import pandas as pd
 
 log = logging.getLogger(__name__)
-logging.basicConfig(level=logging.DEBUG)
+log.setLevel(logging.DEBUG)
 
 DEFAULT_LANG = 'en'
 DIALOG_TREE_FILEPATH = Path(DATA_DIR) / 'chat' / 'moia-poly-dialog-tree-simplified-chinese.v4.dialog.yml'
