@@ -29,7 +29,7 @@ from pathlib import Path
 import subprocess
 import yaml
 
-from qary.config import DATA_DIR, BASE_DIR, MAX_LEN_FILEPATH
+from qary.constants import DATA_DIR, BASE_DIR, MAX_LEN_FILEPATH
 
 logger = logging.getLogger(__name__)
 
