@@ -12,8 +12,8 @@ from boto3.s3.transfer import S3Transfer
 from tqdm import tqdm
 from botocore.exceptions import NoCredentialsError
 
-from qary.config import DATA_DIR, HOME_DIR, BASE_DIR
-from qary.services import SPACES_ACCESS_KEY, SPACES_SECRET_KEY
+from qary.constants import DATA_DIR, HOME_DIR, BASE_DIR
+from qary.constants import SPACES_ACCESS_KEY, SPACES_SECRET_KEY
 from qary.etl.fileutils import LARGE_FILES
 from qary.re_patterns import cre_url
 
