@@ -12,7 +12,7 @@ import requests
 from edit_distance import edit_distance
 
 from qary.spacy_language_model import nlp
-from qary.config import DATA_DIR
+from qary.constants import DATA_DIR
 from qary.etl import wikititles
 
 
