@@ -10,7 +10,7 @@ import pandas as pd
 # from multiprocessing import cpu_count
 
 from qary.etl.netutils import download_if_necessary
-from qary.config import MIDATA_URL, MIDATA_QA_MODEL_DIR, DEFAULT_SKILL_CONFIDENCE, CLI_ARGS  # , USE_CUDA
+from qary.constants import MIDATA_URL, MIDATA_QA_MODEL_DIR, DEFAULT_SKILL_CONFIDENCE, CLI_ARGS  # , USE_CUDA
 from qary.etl.fileutils import LARGE_FILES
 from qary.etl.nesting import dict_merge
 
