@@ -1,5 +1,5 @@
 import yaml
-from qary.config import DATA_DIR
+from qary.constants import DATA_DIR
 from pathlib import Path
 
 
