@@ -4,7 +4,7 @@ import logging
 # import pandas as pd
 
 from qary.etl import faqs
-from qary.config import DOMAINS, FAQ_MIN_SIMILARITY  # , FAQ_MAX_NUM_REPLIES
+from qary.constants import DOMAINS, FAQ_MIN_SIMILARITY  # , FAQ_MAX_NUM_REPLIES
 from qary.skills.base import BotReply
 # from qary import spacy_language_model
 from qary.etl import knowledge_extraction as extract  # noqa
