@@ -3,7 +3,7 @@ import logging
 
 # import pandas as pd
 
-from qary.config import GLOSSARY_DOMAINS
+from qary.constants import GLOSSARY_DOMAINS
 from qary.etl import glossaries
 from qary import spacy_language_model
 from qary.etl import knowledge_extraction as extract
