@@ -5,10 +5,10 @@ from pathlib import Path
 import yaml
 from copy import deepcopy
 
-from qary.config import DATA_DIR
-from qary.config import FINISH_STATE_NAME, EXIT_STATE_NAME, DEFAULT_STATE_NAME
-from qary.config import DEFAULT_BOT_USERNAME, EXIT_BOT_STATEMENTS, EXIT_STATE_TURN_DICT
-from qary.config import WELCOME_STATE_NAME
+from qary.constants import DATA_DIR
+from qary.constants import FINISH_STATE_NAME, EXIT_STATE_NAME, DEFAULT_STATE_NAME
+from qary.constants import DEFAULT_BOT_USERNAME, EXIT_BOT_STATEMENTS, EXIT_STATE_TURN_DICT
+from qary.constants import WELCOME_STATE_NAME
 from qary.etl.nesting import lod_replace
 from qary.etl.utils import normalize_wikititle as default_normalizer
 from qary.chat.dialog_managers import DialogManager
