@@ -2,7 +2,7 @@
 import logging
 from pathlib import Path
 
-from qary.config import DATA_DIR, QUIZ_DOMAINS
+from qary.constants import DATA_DIR, QUIZ_DOMAINS
 # from qary.skills.base import ContextBaseSkill
 
 from qary.chat import dialog
