@@ -8,8 +8,8 @@ import os
 import numpy as np
 
 from qary.chat.dialog_parse import DialogTurns
-from qary.config import DATA_DIR
-from qary.config import FINISH_STATE_NAME
+from qary.constants import DATA_DIR
+from qary.constants import FINISH_STATE_NAME
 from qary.etl.faqs import normalize_docvectors
 from qary.spacy_language_model import nlp
 
